==> noodle-0.0.1.tgz: package/README.md <==
# noodle

Very simple [Oodle API](http://developer.oodle.com/) wrapper.

## Installation

    $ npm install noodle

## Usage 

    var noodle = require('noodle')
      , sys = require('sys')

    const API_KEY = "<<YOUR API KEY>>"

    var params = { apiKey: API_KEY
                 , region: 'usa'
                 , num: 5
                 , q: 'longboard'
                 }

    noodle.fetchListings(params, function(data) {
      console.log(data)
    })

## License

MIT License

Copyright (C) 2011 by Derrick Weis &lt;derrick@derrickweis.com&gt;

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

==> noodle-0.0.3.tgz: package/README.md <==
# noodle

Very simple [Oodle API](http://developer.oodle.com/) wrapper for Node.JS.

## Installation

    $ npm install noodle

## Usage 

    var noodle = require('noodle')
      , sys = require('sys')

    const API_KEY = "<<YOUR API KEY>>"

    var params = { apiKey: API_KEY
                 , region: 'usa'
                 , num: 5
                 , q: 'longboard'
                 }

    noodle.fetchListings(params, function(err, data) {
      console.log(data)
    })

## License

MIT License

Copyright (C) 2011 by Derrick Weis &lt;derrick@derrickweis.com&gt;

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
